(function ($) {

    var quite = {};

    $.fn.overClass = function () {

        var onMouseEnter = $.debounce(100, true, function () {
                $(this).addClass("mouse-over");
            }.bind(this)),

            onMouseLeave = $.debounce(100, true, function () {
                $(this).removeClass("mouse-over");
            }.bind(this))
            ;

        $(this).off("mouseenter", onMouseEnter);
        $(this).on("mouseenter", onMouseEnter);
        $(this).off("mouseleave", onMouseLeave);
        $(this).on("mouseleave", onMouseLeave);

        return this;
    };

    /**
     *
     */

    quite.removePreloader = function () {
        var $preloader = $("#body-preloader"),
            $inner = $preloader.find(".spinner-wrap")
            ;

        $inner.remove();
        if (Modernizr.cssanimations) {
            $preloader.addClass("animated fadeOut").one("webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend", function () {
                $preloader.remove();
            });
        }
        else {
            $preloader.fadeOut(2000, function () {
                $preloader.remove();
            });
        }
    };

    quite.mobileCheck = function () {
        var ua = navigator.userAgent.toLowerCase();

        this.android = ua.indexOf("android") > -1;
        this.iPhone = navigator.userAgent.match(/iPhone/i);
        this.iPad = navigator.userAgent.match(/iPad/i);
        this.mobile = this.android || this.iPhone || this.iPad;

        this.ie = $("html").hasClass("ie");

        if (!this.mobile) {
            $("body").addClass("desktop");
            $("html").addClass("desktop");
        }
        else {
            $("body").addClass("mobile");
            $("html").addClass("mobile");
        }
    };


    /**
     * Google map section
     */

    initMap = function () {

        var _this = quite,
            $contactsPopup = $("#contacts-popup"),
            $cf7 = $("#contact-form-wrap"),
            $map = $("#map_canvas"),
            $markerButton = $(".marker-button"),
            $marker = $(".map-marker"),
            $popupClose = $(".close-popup")
            ;

        $popupClose.click(function () {
            $contactsPopup.removeClass("fadeIn").addClass("fadeOut").one('webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend', function () {
                $contactsPopup.removeClass("on");
            });
        });

        var mapOptions = {
            zoom: Number($map.attr("data-zoom")) || 13,
            mapTypeId: google.maps.MapTypeId.ROADMAP,
            scrollwheel: false,
            draggable: !_this.mobile,
            mapTypeControl: true,
            mapTypeControlOptions: {
                style: google.maps.MapTypeControlStyle.SMALL,
                position: google.maps.ControlPosition.TOP_CENTER
            },
            zoomControl: true,
            zoomControlOptions: {
                style: google.maps.ZoomControlStyle.LARGE,
                position: google.maps.ControlPosition.LEFT_CENTER
            },
            scaleControl: true,
            streetViewControl: true,
            streetViewControlOptions: {
                position: google.maps.ControlPosition.LEFT_CENTER
            }
        };

        var image = templateDirectory + '/img/marker.png',
            tmpImage = new Image(),
            imageHeight = 62;

        tmpImage.src = image;
        $(tmpImage).load(function () {
            imageHeight = $(tmpImage).prop("naturalHeight");
        });

        var latlng = new google.maps.LatLng($map.attr("data-lat"), $map.attr("data-lng"));

        mapOptions.center = latlng;

        map = new google.maps.Map(document.getElementById('map_canvas'), mapOptions);

        var marker = new google.maps.Marker({
            map: map,
            draggable: false,
            position: latlng,
            icon: image
        });

        var overlay = new google.maps.OverlayView();
        overlay.draw = function () {
        };
        overlay.setMap(map);

        $markerButton.on('click', function () {
            $contactsPopup.removeClass("fadeOut").addClass("animated fadeIn on");
        });

        var markerHeight = $marker.outerHeight(true);

        function setMarker() {
            var proj = overlay.getProjection(),
                pos = marker.getPosition(),
                p = proj.fromLatLngToContainerPixel(pos);
            if ($(window).width() < 768) {
                $marker.css({top: "", left: ""});
            }
            else {
                $marker.css({top: p.y - markerHeight / 2 - imageHeight / 2 + 10 + "px", left: p.x + 50 + "px"});
            }
        }

        $(window).on("debouncedresize", function () {
            google.maps.event.trigger(map, 'resize');
            setTimeout(function () {
                map.panTo(latlng);
                setMarker();
            }, 300);
        });

        google.maps.event.addListener(map, 'center_changed', function () {
            setMarker();
        });

        google.maps.event.addListener(map, 'zoom_changed', function () {
            setMarker();
        });

        google.maps.event.trigger(map, 'resize');

        var onLoadInterval = setInterval(function () {
            if (overlay && overlay.getProjection() && marker) {
                clearInterval(onLoadInterval);
                map.panTo(latlng);
                google.maps.event.trigger(map, 'center_changed');
                setMarker();
            }
        }, 10);
    };

    quite.initSectionGMap = function () {
        var el = $('#map_canvas'),
            $contactsPopup = $("#contacts-popup"),
            $wrap = $(".gmap-wrap"),
            _this = this;

        if (el.length == 0) return;

        function resizeMap() {
            var $adminbar = $("#wpadminbar"),
                offset = $adminbar.length ? $adminbar.height() : 0
                ;

            $wrap.width($(window).width()).height($(window).height() - offset);
        }

        $(window).on("debouncedresize", resizeMap);
        resizeMap();

        /**
         * Asynchronous gmap
         * @type {HTMLElement}
         */

        var script = document.createElement('script');
        script.type = 'text/javascript';
        script.src = 'https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false&' +
        'callback=initMap';
        document.body.appendChild(script);
    };

    /**
     *
     */

    quite.backToTop = function () {
        var $footerBar = $("#footer-bar"),
            $appBar = $("#main-app-bar"),
            $audio = $("#footer-audio"),
            $b2top = $('#back-to-top'),
            $toggleSidebar = $("#toggle-sidebar");

        function checkScroll() {
            if ($(window).scrollTop() > 100) {
                $footerBar.addClass("filled");
                $appBar.addClass("filled");
                $audio.trigger("addfill");
            } else {
                $footerBar.removeClass("filled");
                $appBar.removeClass("filled");
                $audio.trigger("nofill");
            }
        }

        function b2top() {
            $('body,html').animate({
                scrollTop: 0
            }, 800);
            return false;
        }

        function sidebarToggle() {
            $toggleSidebar.off("click");
            $toggleSidebar.on("click", function () {
                $appBar.toggleClass("shown");
            });

        }

        function resizeCheck() {
            if ($(window).width() > 480) {
                $(window).off("scroll", checkScroll);
                $(window).on("scroll", checkScroll);

                $b2top.off("click", b2top);
                $b2top.on("click", b2top);
            }
            else {
                $footerBar.addClass("filled");
                $appBar.addClass("filled");
                sidebarToggle();
            }
        }

        resizeCheck();
        $(window).on("debouncedresize", resizeCheck);

        setTimeout(function () {
            $appBar.toggleClass("shown");
        }, 3000);
    };

    quite.showHideSocial = function () {
        var $social = $("#footer-social"),
            $ul = $social.find(".social-icons"),
            itemsLength = $ul.find("li").length,
            boxWidth = $(window).width() < 480 ? 50 : 90,
            offset = boxWidth + 20 + itemsLength * 50;

        $ul.width(itemsLength * 50);

        $social.overClass();

        if (!$social.length) return;

        function setOffset() {
            boxWidth = $(window).width() < 480 ? 50 : 90;
            offset = boxWidth + 20 + $ul.width();
        }

        setOffset();

        /** responsive position fix */

        function resetSocialOnResize() {
            if (!$social.hasClass("open")) { // reverse logic, we just reset position
                $ul.css({
                    //"transform": "translateX(-" + offset + "px)"
                    "transform": "translateX(-300%)"
                });
            }
            else {
                $ul.css({
                    "transform": "translateX(0)"
                });
            }
        }

        function hideSocial(){
            if(!$social.hasClass("mouse-over") && $social.hasClass("open")){
                $ul.css({
                    "transform": "translateX(-300%)"
                });
                $social.toggleClass("open");
            }
        }
        $(window).on("hidesocial", hideSocial);

        /** show/hide on click */

        $social.off("click");
        $social.on("click", function () {
            if ($(this).hasClass("open")) {
                $ul.css({
                    //"transform": "translateX(-" + offset + "px)"
                    "transform": "translateX(-300%)"
                });
            }
            else {
                $ul.css({
                    "transform": "translateX(0)"
                });
            }
            $(this).toggleClass("open");
        });

        $ul.css({
            //"transform": "translateX(-" + offset + "px)"
            "transform": "translateX(-300%)"
        });

        $(window).on("debouncedresize", function () {
            setOffset();
            resetSocialOnResize();
        });
    };

    /** mac detect */

    quite.detectMac = function () {
        this.isMac = navigator.platform.toUpperCase().indexOf('MAC') >= 0;
    };

    //=====================
    //=====================
    //== MENU ACTIONS
    //=====================
    //=====================

    quite.menuToggle = function () {

        var $toggle = $("#main-menu-toggle"),
            menu = $("#main-menu"),
            $menuWrap = $("#menu-wrap"),
            menuOpen = window.themeOptions.menuOpen,
            menuAnimation = window.themeOptions.menuAnimation;

        var $topLevel = $menuWrap.find(".menu > li");

        $menuWrap.overClass();

        //=====================
        //== MENU CLICK HANDLER
        //=====================

        $toggle.click(function () {
            var $btn = $(this);

            if ($(window).width() >= 768) { // tablet/desktop animation

                //=======================
                //== MENU CLOSE
                //=======================
                if ($(this).hasClass("on")) {

                    //=======================
                    //== MENU CLOSE ANIMATED
                    //=======================
                    if (menuAnimation == "1") {
                        $menuWrap.addClass("hide-children");

                        $topLevel.each(function (index) {
                            var $item = $(this);
                            setTimeout(function () {
                                $item.addClass("animated menuItemPlayOut").removeClass("menuItemPlay animation-off");
                            }, ($topLevel.length - index - 1) * 20); // reverse order
                        });

                        setTimeout(function () {
                            $menuWrap.addClass("transparent_bg");
                            $menuWrap.addClass("animate-menu-out");
                        }, $topLevel.length * 20 + 200);

                        setTimeout(function () {
                            $menuWrap.css({"transform": "translateY(-100%)"});
                            $btn.toggleClass("on");
                            menu.toggleClass("on");
                            $menuWrap.removeClass("visible-menu");
                            $menuWrap.addClass("initial-animate-done").removeClass("animate-menu"); // in case it isn't there
                        }, $topLevel.length * 20 + 800);
                    }

                    //=======================
                    //== MENU CLOSE non-ANIMATED
                    //=======================
                    else {
                        $menuWrap.css({"transform": "translateY(-100%)"});
                        $btn.toggleClass("on");
                        menu.toggleClass("on");
                        $menuWrap.removeClass("visible-menu");
                    }
                }

                //=======================
                //== MENU OPEN
                //=======================
                else {

                    //=======================
                    //== MENU OPEN ANIMATED
                    //=======================
                    if (menuAnimation == "1") {
                        $topLevel.css("visibility", "hidden");
                        $menuWrap.addClass("animate-menu").removeClass("animate-menu-out");
                        setTimeout(function () {
                            $menuWrap.removeClass("transparent_bg");
                        }, 800);
                        setTimeout(function () {
                            $topLevel.each(function (index) {
                                var $item = $(this);
                                setTimeout(function () {
                                    $item.removeClass("menuItemPlayOut").addClass("animated menuItemPlay").css("visibility", "visible");
                                }, index * 20);
                            });

                            setTimeout(function () {
                                $topLevel.each(function (index) {
                                    var $item = $(this);
                                    $item.addClass("animation-off");
                                });
                                $menuWrap.removeClass("hide-children");
                            }, $topLevel.length * 20 + 200);

                        }, 200);
                        //$menuWrap.css({"margin-top": ""});
                        $menuWrap.css({"transform": "none"});
                        $btn.toggleClass("on");
                        menu.toggleClass("on");
                        $menuWrap.addClass("visible-menu");
                    }
                    //==========================
                    //== MENU OPEN not-ANIMATED
                    //==========================
                    else {
                        $menuWrap.css({"transform": "none"});
                        $btn.toggleClass("on");
                        menu.toggleClass("on");
                        $menuWrap.addClass("visible-menu");
                    }

                    $(window).trigger("stopslideshow");
                }
            }
            else { // mobile version
                if ($(this).hasClass("on")) {
                    //$menuWrap.css({"margin-top": -menuHeight + "px"});
                    $menuWrap.css({"transform": "translateY(-100%)"});
                    $btn.toggleClass("on");
                    menu.toggleClass("on");
                    $menuWrap.removeClass("visible-menu").addClass("initial-animate-done");
                }
                else {
                    //$menuWrap.css({"margin-top": ""});
                    $menuWrap.css({"transform": "none"});
                    $btn.toggleClass("on");
                    menu.toggleClass("on");
                    $menuWrap.addClass("visible-menu");
                }
            }
        });

        //===========================
        //===========================
        //== MENU APPEARANCE ON LOAD
        //===========================
        //===========================

        if ($(window).width() >= 768 && menuAnimation == "1") {
            $topLevel.css("visibility", "hidden");
            $menuWrap.addClass("hide-children");
        }

        //=====================
        //== MENU OPEN ON LOAD
        //=====================

        if (menuOpen == "1") { // menu open on page load is on

            setTimeout(function () {

                if ($(window).width() >= 768) { // tablet/desktop animation

                    //=============================
                    //== MENU OPENING ANIMATED
                    //=============================
                    if (menuAnimation == "1") {
                        $menuWrap.addClass("animate-menu");
                        setTimeout(function () {
                            $menuWrap.removeClass("transparent_bg");
                        }, 800);
                        setTimeout(function () {
                            $topLevel.each(function (index) {
                                var $item = $(this);
                                setTimeout(function () {
                                    $item.addClass("animated menuItemPlay").css("visibility", "visible");
                                }, index * 20);
                            });

                            setTimeout(function () {
                                $topLevel.each(function (index) {
                                    var $item = $(this);
                                    $item.addClass("animation-off");
                                });
                                $menuWrap.removeClass("hide-children");
                            }, $topLevel.length * 20 + 1000);

                        }, 600);

                        var hideMenu = setTimeout(function () {
                            $toggle.trigger("click");
                            setTimeout(function () {
                                $("body").addClass("menu-ready");
                            }, 2800);
                        }, 3000);

                        $menuWrap.one("mouseenter", function () { // if mouse is in menu, don't hide it
                            clearTimeout(hideMenu);
                            $("body").addClass("menu-ready");
                        });
                    }

                    //=============================
                    //== MENU OPENING not-ANIMATED
                    //=============================
                    else {
                        $menuWrap.removeClass("transparent_bg");
                        $("body").addClass("menu-ready");
                        var hideMenuAlt = setTimeout(function () {
                            $toggle.trigger("click");
                        }, 3000);

                        $menuWrap.one("mouseenter", function () { // if mouse is in menu, don't hide it
                            clearTimeout(hideMenuAlt);
                        });
                    }
                }
                else { // mobile menu
                    $toggle.trigger("click");
                    $menuWrap.removeClass("hide-children");
                    $menuWrap.removeClass("transparent_bg");
                }
            }, 500);
        }
        //=======================
        //== MENU CLOSED ON LOAD
        //=======================
        else {
            $menuWrap.css({"transform": "translateY(-100%)"});
            $toggle.removeClass("on");
            menu.removeClass("on");
            $menuWrap.removeClass("transparent_bg");
            $menuWrap.removeClass("visible-menu");
            $menuWrap.removeClass("hide-children");
            $menuWrap.addClass("initial-animate-done");
            $("body").addClass("menu-ready");
        }
    };

    /**
     * Gallery cart
     */

    quite.initGalleryWooCart = function () {
        $(".add-to-cart-gallery").click(function (event) {
            event.preventDefault();
            var $wrap = $(this).parents(".info-block"),
                quantity = $wrap.find("input.quantity").val(),
                product = $wrap.find("input.product_id").val(),
                $variationWrap = $wrap.find(".product-variations"),
                $variation = $variationWrap.find('input[type="radio"]:checked'),
                variation = $variationWrap.length ? $variation.val() : '',
                $messageWindow = $wrap.find(".message-window"),
                messageSuccess = '<i></i><span>Successfully added to <a target="_blank" href="' + window.cartUrl + '">cart</a>!</span>',
                messageError = '<i></i><span>Couldn\'t add to cart.</span>',
                ajaxData = {
                    action: "gallery_add_to_cart",
                    product_id: product,
                    variation_id: variation,
                    variation_html: $variation.attr("data-html"),
                    variation_attributes: $variation.attr("data-attributes"),
                    quantity: quantity
                }
                ;

            $messageWindow.html('');
            $messageWindow.removeClass("success").removeClass("error").removeClass("loading");
            $messageWindow.addClass("loading");
            setTimeout(function () { // wait for animation end
                $messageWindow.html('<div class="loadingspin"></div>');
            }, 300);

            $.ajax({
                type: "POST",
                url: adminAjax,
                data: ajaxData,
                dataType: 'json',
                success: function (response) {
                    $messageWindow.html('');
                    $messageWindow.removeClass("loading");

                    if (response.result) {
                        $messageWindow.html('');
                        $messageWindow.addClass("success");
                        $messageWindow.html(messageSuccess);
                    }
                    else {
                        $messageWindow.html('');
                        $messageWindow.addClass("error");
                        $messageWindow.html(messageError);
                    }
                },
                error: function (response) {
                    console.log("Shop connection error");
                }
            });
        });
    };

    quite.initLazyLoad = function () {
        //$(".lazy-load").lazyLoad({
        //    event: "loadnow"
        //}).trigger("loadnow");
    };

    quite.initBGVideo = function () {
        $(".js-centered-video-bg").each(function () {
            var $container = $(this),
                video = $container.find("video"),
                videoEl = video.get(0),
                vw = 0,
                vh = 0,
                vr = 0;

            function resizeVideo() {
                var cw = $container.width(),
                    ch = $container.height(),
                    cr = cw / ch
                    ;

                if (cr < vr) {
                    video.css({
                        height: ch,
                        width: 'auto',
                        marginTop: 0,
                        marginLeft: -1 * (ch * vr - cw) / 2
                    });
                }
                else {
                    video.css({
                        width: cw,
                        height: 'auto',
                        marginTop: -1 * ( cw / vr - ch ) / 2,
                        marginLeft: 0
                    });
                }
            }

            videoEl.addEventListener("loadedmetadata", function (e) {
                vw = this.videoWidth;
                vh = this.videoHeight;
                vr = vw / vh;

                resizeVideo();
                $(window).on("debouncedresize", resizeVideo);
            }, false);

            $container.on('mouseenter', function () {
                video.get(0).play();
            });

            $container.on('mouseleave', function () {
                video.get(0).pause();
            });
        });
    };

    quite.topAboutBtn = function () {
        var $btn = $("#top_about_btn"),
            $wrap = $btn.parent();
        $btn.on("click", function () {
            $wrap.toggleClass("open");
            return false;
        });
    };

    quite.mainAppBar = function () {
        var $bar = $("#main-app-bar"),
            $items = $bar.find(".app-bar-item").not("#bar-link");

        if (!$bar.length || !$items.length) return;

        $items.each(function () {
            var $item = $(this),
                $label = $item.find(".bar-item-label"),
                $content = $item.find(".bar-content");

            $item.overClass();

            $label.off("click");
            $label.on("click", function (event) {
                if (!$item.hasClass("open")) {
                    $items.removeClass("open");
                    $item.addClass("open");
                }
                else {
                    $items.removeClass("open");
                }
                event.stopPropagation(); // this is to hide infobuttons
            });

            $content.off("click");
            $content.on("click", function (event) {
                event.stopPropagation();
            });
        });

        /**
         * Hide info buttons
         */

        function hideAll() {
            $items.not(".mouse-over").removeClass("open");
        }
        $(window).on("hideinfo", hideAll);
    };

    quite.contentClickHandler = function(){
        $('html').click(function () { // this is to hide infobuttons
            $(window).trigger("hideinfo").trigger("hidesocial");
        });
    };

    quite.audioPlayer = function () {
        var $footerAudio = $("#footer-audio"),
            audio = $footerAudio.find("audio"),
            $i = $footerAudio.find("i")
            ;

        $footerAudio.click(function () {
            if (!audio.prop("paused")) {
                audio.get(0).pause();
                $i.removeClass("icon-device_volume_loudspeaker_speaker").addClass("icon-device_volume_loudspeaker_speaker_up");
            }
            else {
                audio.get(0).play();
                $i.addClass("icon-device_volume_loudspeaker_speaker").removeClass("icon-device_volume_loudspeaker_speaker_up");
            }
        });
    };

    quite.portfolioVideo = function () {
        var $gallery = $("#portfolio-gallery");
        if ($gallery.hasClass("type-video")) {
            $gallery.videoHelper({
                viewport: $("#video-wrap"),
                mode: "fitWidth"
            });
        }
    };

    quite.portfolioHoverEffect = function () {
        var $grid = $(".gridifier");

        if (!$grid.length /*|| ($grid.attr("data-type") !== 'justified' && $grid.attr("data-type") !== 'metro')*/) return;

        (function () {
            $(function () {
                var columns, current, easing, grid, hideItem, showItem, time;
                grid = $grid;
                var type = $grid.attr("data-type");
                current = {
                    index: -1,
                    column: 0,
                    line: 0
                };
                columns = Number($grid.attr("data-cols"));
                $(window).on("updatecols", function () {
                    columns = Number($grid.attr("data-cols-responsive"));
                });
                easing = "cubic-bezier(0.165, 0.840, 0.440, 1.000)";
                time = 400;
                grid.on("mouseenter", ".grid-item", (function (_this) {
                    return function (e) {
                        var column, el, image, index, info, item, line;
                        el = $(e.currentTarget);
                        info = el.find(".portfolio-content");
                        image = el.find(".portfolio-image");
                        index = el.index();
                        var left = 0, top = 0, cLeft = 0, cTop = 0;
                        column = index % columns;
                        line = Math.floor(index / columns);

                        item = {
                            el: el,
                            index: index,
                            column: column,
                            line: line,
                            info: info,
                            image: image
                        };
                        if (current.el && current.index === index) {
                            return;
                        }
                        if ("justified" == type) {
                            if (line === current.line && column > current.column) {
                                showItem(item, "-100%", 0, "25%", 0);
                                hideItem(current, "100%", 0, "-25%", 0);
                            } else if (line === current.line && column < current.column) {
                                showItem(item, "100%", 0, "-25%", 0);
                                hideItem(current, "-100%", 0, "25%", 0);
                            } else if (line > current.line && column === current.column) {
                                showItem(item, 0, "-100%", 0, "25%");
                                hideItem(current, 0, "100%", 0, "-25%");
                            } else {
                                showItem(item, 0, "100%", 0, "-25%");
                                hideItem(current, 0, "-100%", 0, "25%");
                            }
                        }
                        else { // metro & masonry
                            left = $(el).attr("data-left") ? Number($(el).attr("data-left").replace("px", "").replace("%", "")) : 0;
                            top = $(el).attr("data-top") ? Number($(el).attr("data-top").replace("px", "").replace("%", "")) : 0;
                            cLeft = $(current.el).attr("data-left") ? Number($(current.el).attr("data-left").replace("px", "").replace("%", "")) : 0;
                            cTop = $(current.el).attr("data-top") ? Number($(current.el).attr("data-top").replace("px", "").replace("%", "")) : 0;

                            //console.log(left, top, cLeft, cTop);

                            if ("metro" == type) { // metro, top bottom priority
                                if (top > cTop) {
                                    //console.log("to top");
                                    showItem(item, 0, "-100%", 0, "25%");
                                    hideItem(current, 0, "100%", 0, "-25%");
                                } else if (top < cTop) {
                                    //console.log("to bottom");
                                    showItem(item, 0, "100%", 0, "-25%");
                                    hideItem(current, 0, "-100%", 0, "25%");
                                }
                                else if (left > cLeft) {
                                    //console.log("to right");
                                    showItem(item, "-100%", 0, "25%", 0);
                                    hideItem(current, "100%", 0, "-25%", 0);
                                } else if (left < cLeft) {
                                    //console.log("to left");
                                    showItem(item, "100%", 0, "-25%", 0);
                                    hideItem(current, "-100%", 0, "25%", 0);
                                }
                                else {
                                    //console.log("default to top");
                                    showItem(item, 0, "-100%", 0, "25%");
                                    hideItem(current, 0, "100%", 0, "-25%");
                                }
                            }
                            else { // masonry, left right priority

                                if (left > cLeft) {
                                    //console.log("to right");
                                    showItem(item, "-100%", 0, "25%", 0);
                                    hideItem(current, "100%", 0, "-25%", 0);
                                } else if (left < cLeft) {
                                    //console.log("to left");
                                    showItem(item, "100%", 0, "-25%", 0);
                                    hideItem(current, "-100%", 0, "25%", 0);
                                }
                                else if (top > cTop) {
                                    //console.log("to top");
                                    showItem(item, 0, "-100%", 0, "25%");
                                    hideItem(current, 0, "100%", 0, "-25%");
                                } else if (top < cTop) {
                                    //console.log("to bottom");
                                    showItem(item, 0, "100%", 0, "-25%");
                                    hideItem(current, 0, "-100%", 0, "25%");
                                }
                                else {
                                    //console.log("default to top");
                                    showItem(item, 0, "-100%", 0, "25%");
                                    hideItem(current, 0, "100%", 0, "-25%");
                                }
                            }

                        }
                        return current = item;
                    };
                })(this));


                showItem = function (item, infoX, infoY, imageX, imageY) {
                    item.info.stop().css({
                        x: infoX,
                        y: infoY,
                        display: "block"
                    }).transition({
                        x: 0,
                        y: 0,
                        duration: time,
                        easing: easing
                    });
                    return item.image.stop().transition({
                        x: imageX,
                        y: imageY,
                        opacity: .5,
                        duration: time,
                        easing: easing
                    });
                };
                return hideItem = function (item, infoX, infoY, imageX, imageY) {
                    if (!item.el) {
                        return;
                    }
                    item.info.stop().transition({
                        x: infoX,
                        y: infoY,
                        duration: time,
                        easing: easing
                    });
                    return item.image.stop().css({
                        x: imageX,
                        y: imageY,
                        opacity: .5
                    }).transition({
                        x: 0,
                        y: 0,
                        opacity: 1,
                        duration: time,
                        easing: easing
                    });
                };
            });

        }).call(this);
    };

    /**
     *
     */

    quite.portfolioLikes = function () {
        var $grid = $(".gridifier");

        $grid.find("a.pf-like").each(function () {

            var $btn = $(this),
                $item = $(this).parents(".grid-item"),
                id = Number($item.attr("data-post-id"));

            $btn.on("click", function () {

                alert("click");

                if ($(this).hasClass("clicked")) return false;

                $.ajax({
                    type: "POST",
                    url: adminAjax,
                    data: {
                        action: "portfolio_like",
                        postID: id
                    },
                    dataType: 'json',
                    success: function (response) {
                        console.log(response.likes);
                        //active.attr("data-likes-count", response.likes);
                        //active.attr("data-like-clicked", true);
                        //_this.setLikes();
                    },
                    error: function (response) {

                    }
                });

                return false;
            });

        });
    };

    /**
     *
     */

    quite.blogFunctions = function () {

        if (!$("body").hasClass("is-blog")) return;

        $("body").find(".post-gallery").each(function () {
            var $owl = $(this),
                $wrap = $owl.parent(),
                $next = $wrap.find(".blog-gallery-next"),
                $prev = $wrap.find(".blog-gallery-prev"),
                owl;

            $owl.owlCarousel({
                items: 1,
                navigation: false,
                pagination: false,
                autoPlay: true
            });

            owl = $owl.data("owlCarousel");

            $next.on("click", function () {
                $owl.trigger("owl.next")
            });

            $prev.on("click", function () {
                $owl.trigger("owl.prev")
            });
        });
    };

    /**
     *
     */

    quite.audioButton = function () {

        var mainColor = window.themeOptions['mainColor'],
            $wrap = $("#footer-audio");

        function Playback(container, progressCheck) {

            var _this = this;

            this.diameter = 56;
            this.diameterOnHover = 56;
            this.thickness = 1;
            this.iconSize = 12;
            this.lineColor = mainColor;
            this.mobile = false;

            this.diameterStart = this.diameter;
            this.thicknessStart = this.thickness;

            this.isOver = false;
            this.filled = false;
            this.skin = $("body").hasClass("section-dark") ? "dark" : "light";
            this.playing = false;

            this.audio = container.getElementsByTagName('audio')[0];

            this.progress = 0;
            this.progressOffset = 1;

            this.container = container;
            this.progressCheck = function () {
                var value = 0;
                if (_this.audio.currentTime > 0) {
                    value = Math.floor((100 / _this.audio.duration) * _this.audio.currentTime) / 100;
                }
                return value;
            };

            this.mobileCheck = (function () {
                if ($(window).width() < 768) {
                    this.mobile = true;
                    this.audio.pause();
                }
                else {
                    this.mobile = false;
                }
            }).bind(this);
            this.mobileCheck();
            $(window).on("debouncedresize", this.mobileCheck);

            this.canvas = document.createElement('canvas');
            this.canvas.className = 'playback';
            this.canvas.width = this.diameterOnHover;
            this.canvas.height = this.diameterOnHover;
            this.context = this.canvas.getContext('2d');

            this.devicePixelRatio = window.devicePixelRatio || 1;
            this.backingStoreRatio = this.context.webkitBackingStorePixelRatio ||
            this.context.mozBackingStorePixelRatio ||
            this.context.msBackingStorePixelRatio ||
            this.context.oBackingStorePixelRatio ||
            this.context.backingStorePixelRatio || 1;

            this.ratio = this.devicePixelRatio / this.backingStoreRatio;

            this.container.appendChild(this.canvas);

            if (this.devicePixelRatio !== this.backingStoreRatio) {

                var oldWidth = this.canvas.width;
                var oldHeight = this.canvas.height;

                this.canvas.width = oldWidth * this.ratio;
                this.canvas.height = oldHeight * this.ratio;

                this.canvas.style.width = oldWidth + 'px';
                this.canvas.style.height = oldHeight + 'px';

                this.context.scale(this.ratio, this.ratio);
            }

            this.animate();

            $wrap.on('mouseover', function () {
                this.isOver = true;
            }.bind(this));

            $wrap.on('mouseout', function () {
                this.isOver = false;
            }.bind(this));

            $wrap.on("addfill", $.debounce(150, true, function () {
                this.filled = true;
            }).bind(this));

            $wrap.on("nofill", $.debounce(150, true, function () {
                this.filled = false;
            }).bind(this));

            $wrap.on("skinchange", $.debounce(150, true, function () {
                this.skin = $("body").hasClass("section-dark") ? "dark" : "light";
            }).bind(this));
        };

        Playback.prototype.getColor = function (opacity) {
            opacity = opacity || 0.2;
            return this.skin == "dark"
                ?
                (
                    this.filled
                        ?
                        (
                            !this.isOver ? "rgba(0,0,0," + opacity + ")" : "rgba(255,255,255," + opacity + ")"
                        )
                        :
                        (
                            this.isOver ? "rgba(0,0,0," + opacity + ")" : "rgba(255,255,255," + opacity + ")"
                        )
                )
                : // light skin
                (
                    this.filled
                        ?
                        (
                            this.isOver ? "rgba(0,0,0," + opacity + ")" : "rgba(255,255,255," + opacity + ")"
                        )
                        :
                        (
                            !this.isOver ? "rgba(0,0,0," + opacity + ")" : "rgba(255,255,255," + opacity + ")"
                        )
                );
        };

        Playback.prototype.setPlaying = function (value) {

            var wasPlaying = this.playing,
                timeoutHandle;

            if (!this.mobile) {
                if (value) {
                    clearTimeout(timeoutHandle);
                    this.audio.play();
                    $(this.audio).prop("volume", 0);
                    $(this.audio).stop().animate({volume: Number(window.themeOptions.volumeLimit)}, Number(window.themeOptions.fadeIn));
                }
                else {
                    $(this.audio).stop().animate({volume: 0}, Number(window.themeOptions.fadeOut));
                    timeoutHandle = setTimeout(function () {
                        this.audio.pause();
                    }.bind(this), Number(window.themeOptions.fadeOut));
                }
                this.playing = value;
            }
        };

        Playback.prototype.isPlaying = function () {
            return this.playing;
        };

        Playback.prototype.animate = function () {

            var progressBefore = this.progress;

            if (this.playing) {
                this.progress = this.progressCheck();
            }
            else {
                this.progress += ( 1 - this.progress ) * 0.1;
                this.progress = this.progress > 0.99999 ? 0.99999 : this.progress;
            }

            if (progressBefore > 0.8 && this.progress < 0.2) {
                this.progressOffset = this.progress;
            }
            this.render();
        };

        Playback.prototype.render = function () {

            var progress = this.progressCheck(),
                radius = ( this.diameter / 2 ) - this.thickness,
                x = this.diameter / 2,
                y = this.diameter / 2,
                iconSize = this.iconSize;

            this.progressOffset += ( 1 - this.progressOffset ) * 0.1;

            var endAngle = ( -Math.PI / 2 ) + ( progress * ( Math.PI * 2 ) );
            var startAngle = ( -Math.PI / 2 ) + ( this.progressOffset * ( Math.PI * 2 ) );

            this.context.save();
            this.context.clearRect(0, 0, this.diameterOnHover, this.diameterOnHover);
            this.context.clearRect(0, 0, this.diameter, this.diameter);

            this.context.translate((this.diameterOnHover - this.diameter) / 2, (this.diameterOnHover - this.diameter) / 2);

            // Draw progress track
            this.context.beginPath();
            this.context.arc(x, y, radius, 0, Math.PI * 2, false);
            this.context.lineWidth = this.thickness;
            this.context.strokeStyle = this.getColor();
            this.context.stroke();

            // Draw progress on top of track
            this.context.beginPath();

            this.context.arc(x, y, radius, 1.5 * Math.PI, 1.5 * Math.PI + 2 * Math.PI * progress);

            this.context.lineWidth = this.thickness;
            this.context.strokeStyle = this.lineColor;//'#fff';
            this.context.stroke();

            this.context.translate(x - ( iconSize / 2 ), y - ( iconSize / 2 ));

            // Draw play/pause icons
            if (this.playing) {
                this.context.fillStyle = this.getColor(1);
                this.context.fillRect(0, 0, iconSize / 2 - 4, iconSize);
                this.context.fillRect(iconSize / 2 + 4, 0, iconSize / 2 - 4, iconSize);
            }
            else {
                this.context.beginPath();
                this.context.translate(2, 0);
                this.context.moveTo(0, 0);
                this.context.lineTo(iconSize - 2, iconSize / 2);
                this.context.lineTo(0, iconSize);
                this.context.fillStyle = this.getColor(1);
                this.context.fill();
            }

            this.context.restore();

        };

        Playback.prototype.on = function (type, listener) {
            this.canvas.addEventListener(type, listener, false);
        };

        Playback.prototype.off = function (type, listener) {
            this.canvas.removeEventListener(type, listener, false);
        };

        var $audioPlayer = $("#audioplayer"),
            $audio = $audioPlayer.find("audio"),
            demoElement = $("#audioplayer").get(0);
        if (!$audioPlayer.length || !$audio.attr("data-src")) {
            return;
        }

        function initAudio() {
            var t = Date.now();
            var p;

            $audio.append('<source src="' + $audio.attr("data-src") + '"></source>');

            p = new Playback(demoElement, false);
            p.setPlaying($(demoElement).attr("data-autoplay") != "0");

            p.on('click', function () {
                t = Date.now();
                p.setPlaying(!p.isPlaying());

                //p.render();
            });
            setInterval(function () {
                p.animate();
            }, 300);
        }

        if ($("body").hasClass("loader-wait")) {
            $(window).on("loader:remove", function () {
                setTimeout(function () {
                    initAudio();
                }, 100);
            });
        }
        else {
            initAudio();
        }
    };

    /**
     * Must be before ready
     */

        //$( 'body' ).on( 'wc_fragments_refreshed', function(){
        //    alert("updated");
        //});
        //
        //$('body').on('added_to_cart', function(){
        //    alert("added");
        //});
        //
        //$( 'body' ).on( 'wc_fragments_loaded', function(){
        //    alert("loaded");
        //});

    quite.customSelectBoxes = function () {

        var $variations = $("table.variations"),
            $selects = $variations.find("select"),
            $reset = $variations.find('.reset_variations'),
            $form = $(".variations_form");

        if (!$.fn.selectbox || typeof $.fn.selectbox !== "function") return;

        if ($variations.length) {
            $selects.each(function () {
                $(this).selectbox();
            });

            var resetSelect = function (event) {
                $selects.each(function () {
                    $(this).selectbox("detach");
                    $(this).selectbox("attach");
                });
            };

            $form.on('woocommerce_update_variation_values', resetSelect);
            $reset.on('click', resetSelect);
        }

        $("#calc_shipping_country").selectbox();

        $(".woocommerce-ordering").find("select").selectbox();
    };

    quite.singlePostHeightFix = function () {
        if (!$("body").hasClass("single-post")) return;

        $(".header-pad").each(function () {
            var $header = $(this),
                $content = $header.parents('article').find(".entry-content"),
                $meta = $header.find(".single-meta");

            function resetHeight() {
                if ($header.height() + $content.height() < $meta.height()) {
                    $header.css({
                        "min-height": $meta.height() + 60 + "px"
                    });
                }
                else {
                    $header.css({
                        "min-height": "0"
                    });
                }
            }

            resetHeight();
            $(window).on("debouncedresize", resetHeight);
        });
    };

    quite.appBarContentBlocks = function () {
        var $appBar = $("#main-app-bar"),
            $blocks = $appBar.find(".bar-content");

        function appBarHeightCheck() {
            setTimeout(function () {

                var wh = $(window).height(),
                    ww = $(window).width(),
                    fh = ww > 767 ? 90 : 50;

                $blocks.each(function () {
                    var $block = $(this),
                        blockTop = $block.offset().top,
                        allowedHeight = wh - blockTop - fh;

                    $block.css({
                        "max-height": ""
                    });

                    if ($block.height() > allowedHeight) {
                        $block.css({
                            "max-height": allowedHeight + "px"
                        });
                        if (!$block.hasClass("w-nice")) {
                            $block.niceScroll({
                                cursorcolor: window.themeOptions['mainColor'], // change cursor color in hex
                                zindex: "1000",
                                cursoropacitymin: 0, // change opacity when cursor is inactive (scrollabar "hidden" state), range from 1 to 0
                                cursoropacitymax: 0.8, // change opacity when cursor is active (scrollabar "visible" state), range from 1 to 0
                                cursorwidth: "0", // cursor width in pixel (you can also write "5px")
                                cursorborder: "none", // css definition for cursor border
                                cursorborderradius: "0", // border radius in pixel for cursor
                                background: "#ffffff", // change css for rail background
                                horizrailenabled: false, // nicescroll can manage horizontal scroll
                                railalign: "right", // alignment of vertical rail
                                smoothscroll: false,
                                hidecursordelay: 400, // set the delay in microseconds to fading out scrollbars
                                oneaxismousemode: false // it permits horizontal scrolling with mousewheel on horizontal only content,
                            });
                            $block.addClass("w-nice");
                        }
                    }
                });

            }, 500);

        }

        $(window).on("debouncedresize", appBarHeightCheck);
        appBarHeightCheck();
    };

    /**
     * NiceScroll for PC
     */

    quite.setNiceScroll = function () {

        $("html").niceScroll({
            cursorcolor: window.themeOptions['mainColor'], // change cursor color in hex
            zindex: "1000",
            cursoropacitymin: 0, // change opacity when cursor is inactive (scrollabar "hidden" state), range from 1 to 0
            cursoropacitymax: 0.8, // change opacity when cursor is active (scrollabar "visible" state), range from 1 to 0
            cursorwidth: "5px", // cursor width in pixel (you can also write "5px")
            cursorborder: "none", // css definition for cursor border
            cursorborderradius: "0", // border radius in pixel for cursor
            background: "#ffffff", // change css for rail background
            horizrailenabled: false, // nicescroll can manage horizontal scroll
            railalign: "right", // alignment of vertical rail
            smoothscroll: false,
            hidecursordelay: 400, // set the delay in microseconds to fading out scrollbars
            oneaxismousemode: false // it permits horizontal scrolling with mousewheel on horizontal only content,
        });

        var $menuLevels = $("#menu-wrap").find(".sub-menu");

        function checkMenuLevels() {
            if ($(window).width() >= 768) {
                $menuLevels.each(function () {
                    var $level = $(this);

                    $level.niceScroll({
                        cursorcolor: window.themeOptions['mainColor'], // change cursor color in hex
                        zindex: "10010",
                        cursoropacitymin: 0, // change opacity when cursor is inactive (scrollabar "hidden" state), range from 1 to 0
                        cursoropacitymax: 0, // change opacity when cursor is active (scrollabar "visible" state), range from 1 to 0
                        cursorwidth: "0", // cursor width in pixel (you can also write "5px")
                        cursorborder: "none", // css definition for cursor border
                        cursorborderradius: "0", // border radius in pixel for cursor
                        background: "#000000", // change css for rail background
                        horizrailenabled: false, // nicescroll can manage horizontal scroll
                        railalign: "right", // alignment of vertical rail
                        smoothscroll: false,
                        hidecursordelay: 0, // set the delay in microseconds to fading out scrollbars
                        oneaxismousemode: false // it permits horizontal scrolling with mousewheel on horizontal only content,
                    });
                    $level.addClass("w-nice");
                });
            }
        }

        $(window).on("debouncedresize", checkMenuLevels);
        checkMenuLevels();

        /** contacts popup */
        $(".contacts-popup-inner").niceScroll({
            cursorcolor: window.themeOptions['mainColor'], // change cursor color in hex
            zindex: "10010",
            cursoropacitymin: 0, // change opacity when cursor is inactive (scrollabar "hidden" state), range from 1 to 0
            cursoropacitymax: 0, // change opacity when cursor is active (scrollabar "visible" state), range from 1 to 0
            cursorwidth: "0", // cursor width in pixel (you can also write "5px")
            cursorborder: "none", // css definition for cursor border
            cursorborderradius: "0", // border radius in pixel for cursor
            background: "#000000", // change css for rail background
            horizrailenabled: false, // nicescroll can manage horizontal scroll
            railalign: "right", // alignment of vertical rail
            smoothscroll: false,
            hidecursordelay: 0, // set the delay in microseconds to fading out scrollbars
            oneaxismousemode: false // it permits horizontal scrolling with mousewheel on horizontal only content,
        });
    };

    quite.isIE = function () {
        var myNav = navigator.userAgent.toLowerCase();
        return (myNav.indexOf('msie') != -1) ? parseInt(myNav.split('msie')[1]) : false;
    };

    /** check IE */

    quite.setIEClasses = function () {
        var $body = $("body");
        if (this.isIE()) {
            $body.addClass("ie");
            if (this.isIE() == 9) {
                $body.addClass("ie9");
            }
            if (this.isIE() == 8) {
                $body.addClass("ie8");
            }
            if (this.isIE() < 8) {
                $body.addClass("ie-old");
            }
        }
    };

    quite.setFitVids = function () {
        if (!$.fn.fitVids || typeof $.fn.fitVids !== 'function') return;
        $("article.format-video").fitVids();
    };

    /**
     * Menu Cookie Check
     */

    quite.checkMenuCookie = function () {
        if (window.themeOptions.menuOpenOnce == "1") {
            if ($.cookie("getphotoMenu") != "shown") {
                window.themeOptions.menuOpen = "1";
                $("body").addClass("menu-open-on-load");
                $.cookie("getphotoMenu", "shown");
            }
            else {
                window.themeOptions.menuOpen = "";
                $("body").removeClass("menu-open-on-load");
            }
        }
    };

    quite.portfolioNextPrev = function () {
        var $next = $("#bar-pf-next"),
            $nextInside = $next.find(".inside"),
            $nextLabel = $next.find(".bar-item-label"),
            $nextA = $next.find("a"),
            $prev = $("#bar-pf-prev"),
            $prevInside = $prev.find(".inside"),
            $prevLabel = $prev.find(".bar-item-label"),
            $prevA = $prev.find("a")
            ;

        $next.off("click");
        $prev.off("click");

        var goNext = function () {
            document.location = $nextA.attr("href");
        };

        var goPrev = function () {
            document.location = $prevA.attr("href");
        };

        $next.on("click", goNext);
        $nextInside.on("click", goNext);
        $nextLabel.on("click", goNext);

        $prev.on("click", goPrev);
        $prevInside.on("click", goPrev);
        $prevLabel.on("click", goPrev);
    };

    /**
     * Init
     */

    $("document").ready(function () {

        var $adminbar = $("#wpadminbar"),
            adminbarHeight = $adminbar.length ? $adminbar.height() : 0,
            $wrapper = $("#main-wrapper"),
            mobileWidth = $(window).width() < 768,
            loaderWait = $("body").hasClass("loader-wait")
            ;

        quite.adminbarHeight = adminbarHeight;
        quite.setIEClasses();
        quite.checkMenuCookie();

        function resizeWindow() {
            $("#main-wrapper").height($(window).height() - adminbarHeight);
        }

        quite.contentClickHandler();
        quite.mainAppBar();

        var $passwordWindow = $(".password-window");
        if ($passwordWindow.length) {
            resizeWindow();
            $(window).on("debouncedresize", resizeWindow);
        }

        quite.initLazyLoad();
        quite.initSectionGMap();
        quite.backToTop();
        quite.mobileCheck();
        quite.detectMac();

        if (!quite.isMac) {
            quite.setNiceScroll();
        }

        quite.initGalleryWooCart();
        quite.initBGVideo();

        quite.portfolioVideo();
        quite.portfolioLikes();
        quite.audioButton();
        quite.blogFunctions();
        quite.customSelectBoxes();

        quite.portfolioHoverEffect();
        quite.singlePostHeightFix();
        quite.portfolioNextPrev();

        quite.setFitVids();

        var $prettyImages = $("article a.prettyphoto");
        $prettyImages.each(function () {
            $(this).attr("rel", $(this).attr("data-rel"));
        });
        $prettyImages.prettyPhoto({default_width: 1920, default_height: 1080});

        if (mobileWidth && !loaderWait) {
            quite.menuToggle();
        }

        setTimeout(function () {
            if (!mobileWidth && !loaderWait) {
                quite.menuToggle();
            }
            quite.showHideSocial();
        }, 300);

        setTimeout(function () {
            if (!loaderWait) {
                quite.removePreloader();
            }
            quite.appBarContentBlocks();
        }, 1000);

        if (loaderWait) {
            $(window).on("loader:remove", function () {
                quite.removePreloader();
                setTimeout(function () {
                    quite.menuToggle();
                }, 1000);
            });
        }

    });

})(jQuery);


